QuicTransport

Struct QuicTransport 

pub struct QuicTransport { /* private fields */ }
Connected QUIC transport. Owns the async runtime, the Quinn endpoint, the connection, and the bidirectional stream used for framed messages.