pub struct QuicTransport { /* private fields */ }Expand description
Connected QUIC transport. Owns the async runtime, the Quinn endpoint, the connection, and the bidirectional stream used for framed messages.